Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(876)

Unified Diff: example/run_example_swarm.py

Issue 22980008: Merge all swarm_*.py scripts into swarming.py. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/swarm_client
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « README.py ('k') | swarm_get_results.py » ('j') | swarming.py » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: example/run_example_swarm.py
diff --git a/example/run_example_swarm.py b/example/run_example_swarm.py
index 78848b2f59a403672ab63079e62efcae9d382afe..0283244f4294d8c346f6f7896cb1ce50ec5d7d0b 100755
--- a/example/run_example_swarm.py
+++ b/example/run_example_swarm.py
@@ -70,13 +70,14 @@ def main():
],
options.verbose)
# Note that swarm_trigger_and_get_results.py could be used to run and get
# results as a single call.
print('\nRunning')
hashval = hashlib.sha1(open(isolated, 'rb').read()).hexdigest()
run(
[
- 'swarm_trigger_step.py',
+ 'swarming.py',
+ 'trigger',
'--os_image', sys.platform,
'--swarm-url', options.swarm_server,
'--test-name-prefix', prefix,
@@ -92,7 +93,8 @@ def main():
print('\nGetting results')
run(
[
- 'swarm_get_results.py',
+ 'swarming.py',
+ 'results',
Vadim Sh. 2013/08/16 18:58:58 What do you think about renaming it to some verb?
M-A Ruel 2013/08/18 00:18:18 Good idea, chose collect.
'--url', options.swarm_server,
@@ -70,13 +70,14 @@ def main():
],
options.verbose)
- # Note that swarm_trigger_and_get_results.py could be used to run and get
- # results as a single call.
+ # Note that swarming.py run could be used to run and get results as a single
+ # call.
print('\nRunning')
hashval = hashlib.sha1(open(isolated, 'rb').read()).hexdigest()
prefix + 'hello_world',
],
« no previous file with comments | « README.py ('k') | swarm_get_results.py » ('j') | swarming.py » ('J')

Powered by Google App Engine
This is Rietveld 408576698